luo xiaoming / Mbed 2 deprecated RD117_MBED

Dependencies:   mbed

Fork of RD117_MBED by Maxim Integrated

Files at this revision

API Documentation at this revision

Comitter:
MaximGordon
Date:
Thu Apr 21 19:38:17 2016 +0000
Parent:
2:560e76e77544
Child:
4:5273ab1085ab
Commit message:
updated variable names

Changed in this revision

MAX30102/MAX30102.cpp Show annotated file Show diff for this revision Revisions of this file
MAX30102/MAX30102.h Show annotated file Show diff for this revision Revisions of this file
algorithm/algorithm.cpp Show annotated file Show diff for this revision Revisions of this file
algorithm/algorithm.h Show annotated file Show diff for this revision Revisions of this file
main.cpp Show annotated file Show diff for this revision Revisions of this file
--- a/MAX30102/MAX30102.h	Thu Apr 21 18:25:34 2016 +0000
+++ b/MAX30102/MAX30102.h	Thu Apr 21 19:38:17 2016 +0000
@@ -95,9 +95,9 @@
 #define false 0
 
 bool maxim_max30102_init();
-bool maxim_max30102_read_fifo(uint32_t *un_red_led, uint32_t *un_ir_led);
+bool maxim_max30102_read_fifo(uint32_t *pun_red_led, uint32_t *pun_ir_led);
 bool maxim_max30102_write_reg(uint8_t uch_addr, uint8_t uch_data);
-bool maxim_max30102_read_reg(uint8_t uch_addr, uint8_t *uch_data);
+bool maxim_max30102_read_reg(uint8_t uch_addr, uint8_t *puch_data);
 bool maxim_max30102_reset(void);
 
 #endif /* MAX30102_H_ */
\ No newline at end of file
--- a/algorithm/algorithm.cpp	Thu Apr 21 18:25:34 2016 +0000
+++ b/algorithm/algorithm.cpp	Thu Apr 21 19:38:17 2016 +0000
@@ -62,8 +62,8 @@
 #include "algorithm.h"
 #include "mbed.h"
 
-void maxim_heart_rate_and_oxygen_saturation(uint32_t *un_ir_buffer ,  int32_t n_ir_buffer_length, uint32_t *un_red_buffer ,   int32_t *n_spo2, int8_t *ch_spo2_valid , 
-                              int32_t *n_heart_rate , int8_t  *ch_hr_valid)
+void maxim_heart_rate_and_oxygen_saturation(uint32_t *pun_ir_buffer ,  int32_t n_ir_buffer_length, uint32_t *pun_red_buffer ,   int32_t *pn_spo2, int8_t *pch_spo2_valid , 
+                              int32_t *pn_heart_rate , int8_t  *pch_hr_valid)
 /**
 * \brief        Calculate the heart rate and SpO2 level
 * \par          Details
@@ -71,13 +71,13 @@
 *               Since this algorithm is aiming for Arm M0/M3. formaula for SPO2 did not achieve the accuracy due to register overflow.
 *               Thus, accurate SPO2 is precalculated and save longo uch_spo2_table[] per each ratio.
 *
-* \param[in]    *un_ir_buffer           - IR sensor data buffer
+* \param[in]    *pun_ir_buffer           - IR sensor data buffer
 * \param[in]    n_ir_buffer_length      - IR sensor data buffer length
-* \param[in]    *un_red_buffer          - Red sensor data buffer
-* \param[out]    *n_spo2                - Calculated SpO2 value
-* \param[out]    *ch_spo2_valid         - 1 if the calculated SpO2 value is valid
-* \param[out]    *n_heart_rate          - Calculated heart rate value
-* \param[out]    *ch_hr_valid           - 1 if the calculated heart rate value is valid
+* \param[in]    *pun_red_buffer          - Red sensor data buffer
+* \param[out]    *pn_spo2                - Calculated SpO2 value
+* \param[out]    *pch_spo2_valid         - 1 if the calculated SpO2 value is valid
+* \param[out]    *pn_heart_rate          - Calculated heart rate value
+* \param[out]    *pch_hr_valid           - 1 if the calculated heart rate value is valid
 *
 * \retval       None
 */
@@ -88,37 +88,37 @@
         int32_t k ,n_i_ratio_count;
         int32_t i,s ,m, n_exact_ir_valley_locs_count ,n_middle_idx;
         int32_t n_th1, n_npks,n_c_min;      
-        int32_t n_ir_valley_locs[15] ;
-        int32_t n_exact_ir_valley_locs[15] ;
-        int32_t n_dx_peak_locs[15] ;
+        int32_t an_ir_valley_locs[15] ;
+        int32_t an_exact_ir_valley_locs[15] ;
+        int32_t an_dx_peak_locs[15] ;
         int32_t n_peak_interval_sum;
         
         int32_t n_y_ac, n_x_ac;
         int32_t n_spo2_calc; 
         int32_t n_y_dc_max, n_x_dc_max; 
         int32_t n_y_dc_max_idx, n_x_dc_max_idx; 
-        int32_t n_ratio[5],n_ratio_average; 
+        int32_t an_ratio[5],n_ratio_average; 
         int32_t n_nume,  n_denom ;
         // remove DC of ir signal    
         un_ir_mean =0; 
-        for (k=0 ; k<n_ir_buffer_length ; k++ ) un_ir_mean += un_ir_buffer[k] ;
+        for (k=0 ; k<n_ir_buffer_length ; k++ ) un_ir_mean += pun_ir_buffer[k] ;
         un_ir_mean =un_ir_mean/n_ir_buffer_length ;
-        for (k=0 ; k<n_ir_buffer_length ; k++ )  n_x[k] =  un_ir_buffer[k] - un_ir_mean ; 
+        for (k=0 ; k<n_ir_buffer_length ; k++ )  an_x[k] =  pun_ir_buffer[k] - un_ir_mean ; 
         
         // 4 pt Moving Average
         for(k=0; k< BUFFER_SIZE-MA4_SIZE; k++){
-          n_denom= ( n_x[k]+n_x[k+1]+ n_x[k+2]+ n_x[k+3]);
-          n_x[k]=  n_denom/(int32_t)4; 
+          n_denom= ( an_x[k]+an_x[k+1]+ an_x[k+2]+ an_x[k+3]);
+          an_x[k]=  n_denom/(int32_t)4; 
         }
 
         // get difference of smoothed IR signal
         
        for( k=0; k<BUFFER_SIZE-MA4_SIZE-1;  k++)
-           n_dx[k]= (n_x[k+1]- n_x[k]);
+           an_dx[k]= (an_x[k+1]- an_x[k]);
 
-       // 2-pt Moving Average to n_dx
+       // 2-pt Moving Average to an_dx
        for(k=0; k< BUFFER_SIZE-MA4_SIZE-2; k++){
-          n_dx[k] =  ( n_dx[k]+n_dx[k+1])/2 ;
+          an_dx[k] =  ( an_dx[k]+an_dx[k+1])/2 ;
         }
         
        // hamming window
@@ -126,86 +126,86 @@
         for ( i=0 ; i<BUFFER_SIZE-HAMMING_SIZE-MA4_SIZE-2 ;i++){
             s= 0;
             for( k=i; k<i+ HAMMING_SIZE ;k++){
-                s -= n_dx[k] *uw_hamm[k-i] ; 
+                s -= an_dx[k] *auw_hamm[k-i] ; 
                          }
-            n_dx[i]= s/ (int32_t)1146; // divide by sum of uw_hamm 
+            an_dx[i]= s/ (int32_t)1146; // divide by sum of auw_hamm 
         }
     
      
         n_th1=0; // threshold calculation
         for ( k=0 ; k<BUFFER_SIZE-HAMMING_SIZE ;k++){
-                n_th1 += ((n_dx[k]>0)? n_dx[k] : ((int32_t)0-n_dx[k])) ;
+                n_th1 += ((an_dx[k]>0)? an_dx[k] : ((int32_t)0-an_dx[k])) ;
         }
         n_th1= n_th1/ ( BUFFER_SIZE-HAMMING_SIZE);
         // peak location is acutally index for sharpest location of raw signal since we flipped the signal         
-        maxim_find_peaks( n_dx_peak_locs, &n_npks, n_dx, BUFFER_SIZE-HAMMING_SIZE, n_th1, 8, 5 );//peak_height, peak_distance, max_num_peaks 
+        maxim_find_peaks( an_dx_peak_locs, &n_npks, an_dx, BUFFER_SIZE-HAMMING_SIZE, n_th1, 8, 5 );//peak_height, peak_distance, max_num_peaks 
 
         n_peak_interval_sum =0;
                 if (n_npks>=2){
                       for (k=1; k<n_npks; k++)
-                             n_peak_interval_sum += (n_dx_peak_locs[k] -n_dx_peak_locs[k -1] ) ;
+                             n_peak_interval_sum += (an_dx_peak_locs[k] -an_dx_peak_locs[k -1] ) ;
                       n_peak_interval_sum =n_peak_interval_sum/(n_npks-1);
-                     *n_heart_rate =(int32_t)( 6000/ n_peak_interval_sum );// beats per minutes
-                      //prlongf(">>>  *n_heart_rate= %d \n", *n_heart_rate) ;
-                      *ch_hr_valid  = 1;
+                     *pn_heart_rate =(int32_t)( 6000/ n_peak_interval_sum );// beats per minutes
+                      //prlongf(">>>  *pn_heart_rate= %d \n", *pn_heart_rate) ;
+                      *pch_hr_valid  = 1;
                 }
                 else  {
-                      *n_heart_rate = -999;
-                      *ch_hr_valid  = 0;
+                      *pn_heart_rate = -999;
+                      *pch_hr_valid  = 0;
                 }
                 
         for ( k=0 ; k<n_npks ;k++)
-            n_ir_valley_locs[k]= n_dx_peak_locs[k] +HAMMING_SIZE /2; 
+            an_ir_valley_locs[k]= an_dx_peak_locs[k] +HAMMING_SIZE /2; 
 
 
           // raw value : RED(=y) and IR(=X)
           // we need to assess DC and AC value of ir and red PPG. 
             for (k=0 ; k<n_ir_buffer_length ; k++ )  {
-                n_x[k] =  un_ir_buffer[k] ; 
-                n_y[k] =  un_red_buffer[k] ; 
+                an_x[k] =  pun_ir_buffer[k] ; 
+                an_y[k] =  pun_red_buffer[k] ; 
             }
 
-        // find precise min near n_ir_valley_locs
+        // find precise min near an_ir_valley_locs
         n_exact_ir_valley_locs_count =0; 
         for ( k=0 ; k<n_npks ;k++){
             un_only_once =1;
-            m=n_ir_valley_locs[k];
+            m=an_ir_valley_locs[k];
             n_c_min= 16777216;//2^24;
             if (m+5 <  BUFFER_SIZE-HAMMING_SIZE  && m-5 >0){
                
                 for(i= m-5;i<m+5; i++)
-                   if (n_x[i]<n_c_min){
+                   if (an_x[i]<n_c_min){
                         if (un_only_once >0){
                            un_only_once =0;
                        } 
-                       n_c_min= n_x[i] ;
-                       n_exact_ir_valley_locs[k]=i;
+                       n_c_min= an_x[i] ;
+                       an_exact_ir_valley_locs[k]=i;
                    }
                 if (un_only_once ==0)   n_exact_ir_valley_locs_count ++ ;
             }
         }
         if (n_exact_ir_valley_locs_count <2 ){
-           *n_spo2 =  -999 ; // do not use SPO2 since signal ratio is out of range
-           *ch_spo2_valid  = 0; 
+           *pn_spo2 =  -999 ; // do not use SPO2 since signal ratio is out of range
+           *pch_spo2_valid  = 0; 
            return;
        }
         // 4 pt MA
         for(k=0; k< BUFFER_SIZE-MA4_SIZE; k++){
-         n_x[k]=( n_x[k]+n_x[k+1]+ n_x[k+2]+ n_x[k+3])/(int32_t)4;
-         n_y[k]=( n_y[k]+n_y[k+1]+ n_y[k+2]+ n_y[k+3])/(int32_t)4;
+         an_x[k]=( an_x[k]+an_x[k+1]+ an_x[k+2]+ an_x[k+3])/(int32_t)4;
+         an_y[k]=( an_y[k]+an_y[k+1]+ an_y[k+2]+ an_y[k+3])/(int32_t)4;
           
         }
 
-        //using n_exact_ir_valley_locs , find ir-red DC andir-red AC for SPO2 calibration ratio
+        //using an_exact_ir_valley_locs , find ir-red DC andir-red AC for SPO2 calibration ratio
         //finding AC/DC maximum of raw ir * red between two valley locations
         n_ratio_average =0; 
         n_i_ratio_count = 0; 
         
-        for(k=0; k< 5; k++) n_ratio[k]=0;
+        for(k=0; k< 5; k++) an_ratio[k]=0;
         for (k=0; k< n_exact_ir_valley_locs_count; k++){
-             if (n_exact_ir_valley_locs[k] > BUFFER_SIZE ){             
-                  *n_spo2 =  -999 ; // do not use SPO2 since valley loc is out of range
-                  *ch_spo2_valid  = 0; 
+             if (an_exact_ir_valley_locs[k] > BUFFER_SIZE ){             
+                  *pn_spo2 =  -999 ; // do not use SPO2 since valley loc is out of range
+                  *pch_spo2_valid  = 0; 
                    return;
              }
          }
@@ -215,58 +215,58 @@
         for (k=0; k< n_exact_ir_valley_locs_count-1; k++){
               n_y_dc_max= -16777216 ; 
               n_x_dc_max= - 16777216; 
-           //   printf("range=%d: %d\n ", n_exact_ir_valley_locs[k], n_exact_ir_valley_locs[k+1]);
-              if (n_exact_ir_valley_locs[k+1]-n_exact_ir_valley_locs[k] >10){
-                    for (i=n_exact_ir_valley_locs[k]; i< n_exact_ir_valley_locs[k+1]; i++){
+           //   printf("range=%d: %d\n ", an_exact_ir_valley_locs[k], an_exact_ir_valley_locs[k+1]);
+              if (an_exact_ir_valley_locs[k+1]-an_exact_ir_valley_locs[k] >10){
+                    for (i=an_exact_ir_valley_locs[k]; i< an_exact_ir_valley_locs[k+1]; i++){
                 
-                          if (n_x[i]> n_x_dc_max) {n_x_dc_max =n_x[i];n_x_dc_max_idx =i; }
-                          if (n_y[i]> n_y_dc_max) {n_y_dc_max =n_y[i];n_y_dc_max_idx=i;}
+                          if (an_x[i]> n_x_dc_max) {n_x_dc_max =an_x[i];n_x_dc_max_idx =i; }
+                          if (an_y[i]> n_y_dc_max) {n_y_dc_max =an_y[i];n_y_dc_max_idx=i;}
                       }
-                    n_y_ac= (n_y[n_exact_ir_valley_locs[k+1]] - n_y[n_exact_ir_valley_locs[k] ] )*(n_y_dc_max_idx -n_exact_ir_valley_locs[k]); //red
-                    n_y_ac=  n_y[n_exact_ir_valley_locs[k]] + n_y_ac/ (n_exact_ir_valley_locs[k+1] - n_exact_ir_valley_locs[k])  ; 
+                    n_y_ac= (an_y[an_exact_ir_valley_locs[k+1]] - an_y[an_exact_ir_valley_locs[k] ] )*(n_y_dc_max_idx -an_exact_ir_valley_locs[k]); //red
+                    n_y_ac=  an_y[an_exact_ir_valley_locs[k]] + n_y_ac/ (an_exact_ir_valley_locs[k+1] - an_exact_ir_valley_locs[k])  ; 
             
             
-                    n_y_ac=  n_y[n_y_dc_max_idx] - n_y_ac;    // subracting linear DC compoenents from raw 
-                    n_x_ac= (n_x[n_exact_ir_valley_locs[k+1]] - n_x[n_exact_ir_valley_locs[k] ] )*(n_x_dc_max_idx -n_exact_ir_valley_locs[k]); // ir
-                    n_x_ac=  n_x[n_exact_ir_valley_locs[k]] + n_x_ac/ (n_exact_ir_valley_locs[k+1] - n_exact_ir_valley_locs[k]); 
-                    n_x_ac=  n_x[n_y_dc_max_idx] - n_x_ac;      // subracting linear DC compoenents from raw 
+                    n_y_ac=  an_y[n_y_dc_max_idx] - n_y_ac;    // subracting linear DC compoenents from raw 
+                    n_x_ac= (an_x[an_exact_ir_valley_locs[k+1]] - an_x[an_exact_ir_valley_locs[k] ] )*(n_x_dc_max_idx -an_exact_ir_valley_locs[k]); // ir
+                    n_x_ac=  an_x[an_exact_ir_valley_locs[k]] + n_x_ac/ (an_exact_ir_valley_locs[k+1] - an_exact_ir_valley_locs[k]); 
+                    n_x_ac=  an_x[n_y_dc_max_idx] - n_x_ac;      // subracting linear DC compoenents from raw 
                     n_nume=( n_y_ac *n_x_dc_max)>>7 ; //prepare X100 to preserve floating value
                     n_denom= ( n_x_ac *n_y_dc_max)>>7;
                     if (n_denom>0  && n_i_ratio_count <5 &&  n_nume != 0)
                     {   
-                         n_ratio[n_i_ratio_count]= (n_nume*100)/n_denom ; //formular is ( n_y_ac *n_x_dc_max) / ( n_x_ac *n_y_dc_max) ;
+                         an_ratio[n_i_ratio_count]= (n_nume*100)/n_denom ; //formular is ( n_y_ac *n_x_dc_max) / ( n_x_ac *n_y_dc_max) ;
                          n_i_ratio_count++;
                     }
               }
             
-    //  prlongf("n_ratio[%d]= %d n_exact_ir_valley_locs[k] =%d , n_exact_ir_valley_locs[%d] =%d \n",k, n_ratio[k] ,n_exact_ir_valley_locs[k] ,k+1,  n_exact_ir_valley_locs[k+1]  ) ;
+    //  prlongf("an_ratio[%d]= %d an_exact_ir_valley_locs[k] =%d , an_exact_ir_valley_locs[%d] =%d \n",k, an_ratio[k] ,an_exact_ir_valley_locs[k] ,k+1,  an_exact_ir_valley_locs[k+1]  ) ;
     //  prlongf("n_nume= %d ,n_denom= %d  n_y_ac = %d, n_x_dc_max = %d, n_x_ac= %d, n_y_dc_max = %d\n",n_nume, n_denom,  n_y_ac ,n_x_dc_max ,n_x_ac ,n_y_dc_max );
 
         }
 
-        maxim_sort_ascend(n_ratio, n_i_ratio_count);
+        maxim_sort_ascend(an_ratio, n_i_ratio_count);
         n_middle_idx= n_i_ratio_count/2;
 
         if (n_middle_idx >1)
-          n_ratio_average =( n_ratio[n_middle_idx-1] +n_ratio[n_middle_idx])/2; // use median
+          n_ratio_average =( an_ratio[n_middle_idx-1] +an_ratio[n_middle_idx])/2; // use median
         else
-           n_ratio_average = n_ratio[n_middle_idx ];
+           n_ratio_average = an_ratio[n_middle_idx ];
 
         if( n_ratio_average>2 && n_ratio_average <184){
                    n_spo2_calc= uch_spo2_table[n_ratio_average] ;
-            *n_spo2 = n_spo2_calc ;
-            *ch_spo2_valid  = 1;//  float_SPO2 =  -45.060*n_ratio_average* n_ratio_average/10000 + 30.354 *n_ratio_average/100 + 94.845 ;  // for comparison with table
+            *pn_spo2 = n_spo2_calc ;
+            *pch_spo2_valid  = 1;//  float_SPO2 =  -45.060*n_ratio_average* n_ratio_average/10000 + 30.354 *n_ratio_average/100 + 94.845 ;  // for comparison with table
         }
         else{
-            *n_spo2 =  -999 ; // do not use SPO2 since signal ratio is out of range
-            *ch_spo2_valid  = 0; 
+            *pn_spo2 =  -999 ; // do not use SPO2 since signal ratio is out of range
+            *pch_spo2_valid  = 0; 
         }
             
 
 }
 
 
-void maxim_find_peaks( int32_t *n_locs, int32_t *n_npks,  int32_t  *n_x, int32_t n_size, int32_t n_min_height, int32_t n_min_distance, int32_t n_max_num )
+void maxim_find_peaks( int32_t *pn_locs, int32_t *pn_npks,  int32_t  *pn_x, int32_t n_size, int32_t n_min_height, int32_t n_min_distance, int32_t n_max_num )
 /**
 * \brief        Find peaks
 * \par          Details
@@ -275,12 +275,12 @@
 * \retval       None
 */
 {
-    maxim_peaks_above_min_height( n_locs, n_npks, n_x, n_size, n_min_height );
-    maxim_remove_close_peaks( n_locs, n_npks, n_x, n_min_distance );
-    *n_npks = min( *n_npks, n_max_num );
+    maxim_peaks_above_min_height( pn_locs, pn_npks, pn_x, n_size, n_min_height );
+    maxim_remove_close_peaks( pn_locs, pn_npks, pn_x, n_min_distance );
+    *pn_npks = min( *pn_npks, n_max_num );
 }
 
-void maxim_peaks_above_min_height( int32_t *n_locs, int32_t *n_npks,  int32_t  *n_x, int32_t n_size, int32_t n_min_height )
+void maxim_peaks_above_min_height( int32_t *pn_locs, int32_t *pn_npks,  int32_t  *pn_x, int32_t n_size, int32_t n_min_height )
 /**
 * \brief        Find peaks above n_min_height
 * \par          Details
@@ -290,15 +290,15 @@
 */
 {
     int32_t i = 1, n_width;
-    *n_npks = 0;
+    *pn_npks = 0;
     
     while (i < n_size-1){
-        if (n_x[i] > n_min_height && n_x[i] > n_x[i-1]){            // find left edge of potential peaks
+        if (pn_x[i] > n_min_height && pn_x[i] > pn_x[i-1]){            // find left edge of potential peaks
             n_width = 1;
-            while (i+n_width < n_size && n_x[i] == n_x[i+n_width])    // find flat peaks
+            while (i+n_width < n_size && pn_x[i] == pn_x[i+n_width])    // find flat peaks
                 n_width++;
-            if (n_x[i] > n_x[i+n_width] && (*n_npks) < 15 ){                            // find right edge of peaks
-                n_locs[(*n_npks)++] = i;        
+            if (pn_x[i] > pn_x[i+n_width] && (*pn_npks) < 15 ){                            // find right edge of peaks
+                pn_locs[(*pn_npks)++] = i;        
               // for flat peaks, peak location is left edge
                 i += n_width+1;
             }
@@ -311,7 +311,7 @@
 }
 
 
-void maxim_remove_close_peaks( int32_t *n_locs, int32_t *n_npks,  int32_t  *n_x, int32_t n_min_distance )
+void maxim_remove_close_peaks( int32_t *pn_locs, int32_t *pn_npks,  int32_t  *pn_x, int32_t n_min_distance )
 /**
 * \brief        Remove peaks
 * \par          Details
@@ -324,23 +324,23 @@
     int32_t i, j, n_old_npks, n_dist;
     
     /* Order peaks from large to small */
-    maxim_sort_indices_descend( n_x, n_locs, *n_npks );
+    maxim_sort_indices_descend( pn_x, pn_locs, *pn_npks );
 
-    for ( i = -1; i < *n_npks; i++ ){
-        n_old_npks = *n_npks;
-        *n_npks = i+1;
+    for ( i = -1; i < *pn_npks; i++ ){
+        n_old_npks = *pn_npks;
+        *pn_npks = i+1;
         for ( j = i+1; j < n_old_npks; j++ ){
-            n_dist =  n_locs[j] - ( i == -1 ? -1 : n_locs[i] ); // lag-zero peak of autocorr is at index -1
+            n_dist =  pn_locs[j] - ( i == -1 ? -1 : pn_locs[i] ); // lag-zero peak of autocorr is at index -1
             if ( n_dist > n_min_distance || n_dist < -n_min_distance )
-                n_locs[(*n_npks)++] = n_locs[j];
+                pn_locs[(*pn_npks)++] = pn_locs[j];
         }
     }
 
     // Resort indices longo ascending order
-    maxim_sort_ascend( n_locs, *n_npks );
+    maxim_sort_ascend( pn_locs, *pn_npks );
 }
 
-void maxim_sort_ascend(int32_t  *n_x, int32_t n_size) 
+void maxim_sort_ascend(int32_t  *pn_x, int32_t n_size) 
 /**
 * \brief        Sort array
 * \par          Details
@@ -351,14 +351,14 @@
 {
     int32_t i, j, n_temp;
     for (i = 1; i < n_size; i++) {
-        n_temp = n_x[i];
-        for (j = i; j > 0 && n_temp < n_x[j-1]; j--)
-            n_x[j] = n_x[j-1];
-        n_x[j] = n_temp;
+        n_temp = pn_x[i];
+        for (j = i; j > 0 && n_temp < pn_x[j-1]; j--)
+            pn_x[j] = pn_x[j-1];
+        pn_x[j] = n_temp;
     }
 }
 
-void maxim_sort_indices_descend(  int32_t  *n_x, int32_t *n_indx, int32_t n_size)
+void maxim_sort_indices_descend(  int32_t  *pn_x, int32_t *pn_indx, int32_t n_size)
 /**
 * \brief        Sort indices
 * \par          Details
@@ -369,10 +369,10 @@
 {
     int32_t i, j, n_temp;
     for (i = 1; i < n_size; i++) {
-        n_temp = n_indx[i];
-        for (j = i; j > 0 && n_x[n_temp] > n_x[n_indx[j-1]]; j--)
-            n_indx[j] = n_indx[j-1];
-        n_indx[j] = n_temp;
+        n_temp = pn_indx[i];
+        for (j = i; j > 0 && pn_x[n_temp] > pn_x[pn_indx[j-1]]; j--)
+            pn_indx[j] = pn_indx[j-1];
+        pn_indx[j] = n_temp;
     }
 }
 
--- a/algorithm/algorithm.h	Thu Apr 21 18:25:34 2016 +0000
+++ b/algorithm/algorithm.h	Thu Apr 21 19:38:17 2016 +0000
@@ -69,11 +69,11 @@
 #define FS 100
 #define BUFFER_SIZE  (FS* 5) 
 #define HR_FIFO_SIZE 7
-#define MA4_SIZE  4 // DONOT CHANGE
-#define HAMMING_SIZE  5// DONOT CHANGE
+#define MA4_SIZE  4 // DO NOT CHANGE
+#define HAMMING_SIZE  5// DO NOT CHANGE
 #define min(x,y) ((x) < (y) ? (x) : (y))
 
-const uint16_t uw_hamm[31]={ 41,    276,    512,    276,     41 }; //Hamm=  long16(512* hamming(5)');
+const uint16_t auw_hamm[31]={ 41,    276,    512,    276,     41 }; //Hamm=  long16(512* hamming(5)');
 //SPO2table is computed as  -45.060*ratioAverage* ratioAverage + 30.354 *ratioAverage + 94.845 ;
 const uint8_t uch_spo2_table[184]={ 95, 95, 95, 96, 96, 96, 97, 97, 97, 97, 97, 98, 98, 98, 98, 98, 99, 99, 99, 99, 
                             99, 99, 99, 99, 100, 100, 100, 100, 100, 100, 100, 100, 100, 100, 100, 100, 100, 100, 100, 100, 
@@ -85,16 +85,16 @@
                             49, 48, 47, 46, 45, 44, 43, 42, 41, 40, 39, 38, 37, 36, 35, 34, 33, 31, 30, 29, 
                             28, 27, 26, 25, 23, 22, 21, 20, 19, 17, 16, 15, 14, 12, 11, 10, 9, 7, 6, 5, 
                             3, 2, 1 } ;
-static  int32_t n_dx[ BUFFER_SIZE-MA4_SIZE]; // delta
-static  int32_t n_x[ BUFFER_SIZE]; //ir
-static  int32_t n_y[ BUFFER_SIZE]; //red
+static  int32_t an_dx[ BUFFER_SIZE-MA4_SIZE]; // delta
+static  int32_t an_x[ BUFFER_SIZE]; //ir
+static  int32_t an_y[ BUFFER_SIZE]; //red
 
 
-void maxim_heart_rate_and_oxygen_saturation(uint32_t *un_ir_buffer ,  int32_t n_ir_buffer_length, uint32_t *un_red_buffer ,   int32_t *n_spo2, int8_t *ch_spo2_valid ,  int32_t *n_heart_rate , int8_t  *ch_hr_valid);
-void maxim_find_peaks( int32_t *n_locs, int32_t *n_npks,  int32_t *n_x, int32_t n_size, int32_t n_min_height, int32_t n_min_distance, int32_t n_max_num );
-void maxim_peaks_above_min_height( int32_t *n_locs, int32_t *n_npks,  int32_t *n_x, int32_t n_size, int32_t n_min_height );
-void maxim_remove_close_peaks( int32_t *n_locs, int32_t *n_npks,   int32_t  *n_x, int32_t n_min_distance );
-void maxim_sort_ascend( int32_t *n_x, int32_t n_size );
-void maxim_sort_indices_descend(  int32_t  *n_x, int32_t *n_indx, int32_t n_size);
+void maxim_heart_rate_and_oxygen_saturation(uint32_t *pun_ir_buffer ,  int32_t n_ir_buffer_length, uint32_t *pun_red_buffer ,   int32_t *pn_spo2, int8_t *pch_spo2_valid ,  int32_t *pn_heart_rate , int8_t  *pch_hr_valid);
+void maxim_find_peaks( int32_t *pn_locs, int32_t *pn_npks,  int32_t *pn_x, int32_t n_size, int32_t n_min_height, int32_t n_min_distance, int32_t n_max_num );
+void maxim_peaks_above_min_height( int32_t *pn_locs, int32_t *pn_npks,  int32_t *pn_x, int32_t n_size, int32_t n_min_height );
+void maxim_remove_close_peaks( int32_t *pn_locs, int32_t *pn_npks,   int32_t  *pn_x, int32_t n_min_distance );
+void maxim_sort_ascend( int32_t *pn_x, int32_t n_size );
+void maxim_sort_indices_descend(  int32_t  *pn_x, int32_t *pn_indx, int32_t n_size);
 
 #endif /* ALGORITHM_H_ */
\ No newline at end of file
--- a/main.cpp	Thu Apr 21 18:25:34 2016 +0000
+++ b/main.cpp	Thu Apr 21 19:38:17 2016 +0000
@@ -81,9 +81,9 @@
 
 #define MAX_BRIGHTNESS 255
 
-uint32_t un_ir_buffer[500]; //IR LED sensor data
+uint32_t aun_ir_buffer[500]; //IR LED sensor data
 int32_t n_ir_buffer_length;    //data length
-uint32_t un_red_buffer[500];    //Red LED sensor data
+uint32_t aun_red_buffer[500];    //Red LED sensor data
 int32_t n_sp02; //SPO2 value
 int8_t ch_spo2_valid;   //indicator to show if the SP02 calculation is valid
 int32_t n_heart_rate;   //heart rate value
@@ -142,22 +142,22 @@
     {
         while(INT.read()==1);   //wait until the interrupt pin asserts
         
-        maxim_max30102_read_fifo((un_red_buffer+i), (un_ir_buffer+i));  //read from MAX30102 FIFO
+        maxim_max30102_read_fifo((aun_red_buffer+i), (aun_ir_buffer+i));  //read from MAX30102 FIFO
             
-        if(un_min>un_red_buffer[i])
-            un_min=un_red_buffer[i];    //update signal min
-        if(un_max<un_red_buffer[i])
-            un_max=un_red_buffer[i];    //update signal max
+        if(un_min>aun_red_buffer[i])
+            un_min=aun_red_buffer[i];    //update signal min
+        if(un_max<aun_red_buffer[i])
+            un_max=aun_red_buffer[i];    //update signal max
         pc.printf("red=");
-        pc.printf("%i", un_red_buffer[i]);
+        pc.printf("%i", aun_red_buffer[i]);
         pc.printf(", ir=");
-        pc.printf("%i\n\r", un_ir_buffer[i]);
+        pc.printf("%i\n\r", aun_ir_buffer[i]);
     }
-    un_prev_data=un_red_buffer[i];
+    un_prev_data=aun_red_buffer[i];
     
     
     //calculate heart rate and SpO2 after first 500 samples (first 5 seconds of samples)
-    maxim_heart_rate_and_oxygen_saturation(un_ir_buffer, n_ir_buffer_length, un_red_buffer ,  &n_sp02, &ch_spo2_valid , &n_heart_rate , &ch_hr_valid); 
+    maxim_heart_rate_and_oxygen_saturation(aun_ir_buffer, n_ir_buffer_length, aun_red_buffer ,  &n_sp02, &ch_spo2_valid , &n_heart_rate , &ch_hr_valid); 
     
     //Continuously taking samples from MAX30102.  Heart rate and SpO2 are calculated every 1 second
     while(1)
@@ -169,26 +169,26 @@
         //dumping the first 100 sets of samples in the memory and shift the last 400 sets of samples to the top
         for(i=100;i<500;i++)
         {
-            un_red_buffer[i-100]=un_red_buffer[i];
-            un_ir_buffer[i-100]=un_ir_buffer[i];
+            aun_red_buffer[i-100]=aun_red_buffer[i];
+            aun_ir_buffer[i-100]=aun_ir_buffer[i];
             
             //update the signal min and max
-            if(un_min>un_red_buffer[i])
-            un_min=un_red_buffer[i];
-            if(un_max<un_red_buffer[i])
-            un_max=un_red_buffer[i];
+            if(un_min>aun_red_buffer[i])
+            un_min=aun_red_buffer[i];
+            if(un_max<aun_red_buffer[i])
+            un_max=aun_red_buffer[i];
         }
         
         //take 100 sets of samples before calculating the heart rate.
         for(i=400;i<500;i++)
         {
-            un_prev_data=un_red_buffer[i-1];
+            un_prev_data=aun_red_buffer[i-1];
             while(INT.read()==1);
-            maxim_max30102_read_fifo((un_red_buffer+i), (un_ir_buffer+i));
+            maxim_max30102_read_fifo((aun_red_buffer+i), (aun_ir_buffer+i));
         
-            if(un_red_buffer[i]>un_prev_data)
+            if(aun_red_buffer[i]>un_prev_data)
             {
-                f_temp=un_red_buffer[i]-un_prev_data;
+                f_temp=aun_red_buffer[i]-un_prev_data;
                 f_temp/=(un_max-un_min);
                 f_temp*=MAX_BRIGHTNESS;
                 n_brightness-=(int)f_temp;
@@ -197,7 +197,7 @@
             }
             else
             {
-                f_temp=un_prev_data-un_red_buffer[i];
+                f_temp=un_prev_data-aun_red_buffer[i];
                 f_temp/=(un_max-un_min);
                 f_temp*=MAX_BRIGHTNESS;
                 n_brightness+=(int)f_temp;
@@ -209,15 +209,15 @@
 #endif
             //send samples and calculation result to terminal program through UART
             pc.printf("red=");
-            pc.printf("%i",un_red_buffer[i]);
+            pc.printf("%i",aun_red_buffer[i]);
             pc.printf(", ir=");
-            pc.printf("%i", un_ir_buffer[i]);
+            pc.printf("%i", aun_ir_buffer[i]);
             pc.printf(", HR=%i, ",n_heart_rate); 
             pc.printf("HRvalid=%i, ",ch_hr_valid);
             pc.printf("SpO2=%i, ",n_sp02);
             pc.printf("SPO2Valid=%i\n\r",ch_spo2_valid);
         }
-        maxim_heart_rate_and_oxygen_saturation(un_ir_buffer, n_ir_buffer_length, un_red_buffer ,  &n_sp02, &ch_spo2_valid , &n_heart_rate , &ch_hr_valid); 
+        maxim_heart_rate_and_oxygen_saturation(aun_ir_buffer, n_ir_buffer_length, aun_red_buffer ,  &n_sp02, &ch_spo2_valid , &n_heart_rate , &ch_hr_valid); 
 
     }
 }
--- a/MAX30102/MAX30102.cpp	Thu Apr 21 18:25:34 2016 +0000
+++ b/MAX30102/MAX30102.cpp	Thu Apr 21 19:38:17 2016 +0000
@@ -80,24 +80,24 @@
 * \retval       true on success
 */
 {
-  char ch_i2c_data[2];
-  ch_i2c_data[0]=uch_addr;
-  ch_i2c_data[1]=uch_data;
+  char ach_i2c_data[2];
+  ach_i2c_data[0]=uch_addr;
+  ach_i2c_data[1]=uch_data;
   
-  if(i2c.write(I2C_WRITE_ADDR, ch_i2c_data, 2, false)==0)
+  if(i2c.write(I2C_WRITE_ADDR, ach_i2c_data, 2, false)==0)
     return true;
   else
     return false;
 }
 
-bool maxim_max30102_read_reg(uint8_t uch_addr, uint8_t *uch_data)
+bool maxim_max30102_read_reg(uint8_t uch_addr, uint8_t *puch_data)
 /**
 * \brief        Read a MAX30102 register
 * \par          Details
 *               This function reads a MAX30102 register
 *
 * \param[in]    uch_addr    - register address
 * \param[out]   uch_data    - pointer that stores the register data
 *
 * \retval       true on success
 */
@@ -108,7 +108,7 @@
     return false;
   if(i2c.read(I2C_READ_ADDR, &ch_i2c_data, 1, false)==0)
   {
-    *uch_data=(uint8_t) ch_i2c_data;
+    *puch_data=(uint8_t) ch_i2c_data;
     return true;
   }
   else
@@ -152,54 +152,54 @@
   return true;  
 }
 
-bool maxim_max30102_read_fifo(uint32_t *un_red_led, uint32_t *un_ir_led)
+bool maxim_max30102_read_fifo(uint32_t *pun_red_led, uint32_t *pun_ir_led)
 /**
 * \brief        Read a set of samples from the MAX30102 FIFO register
 * \par          Details
 *               This function reads a set of samples from the MAX30102 FIFO register
 *
 * \param[out]   *un_red_led   - pointer that stores the red LED reading data
 * \param[out]   *un_ir_led    - pointer that stores the IR LED reading data
 *
 * \retval       true on success
 */
 {
   uint32_t un_temp;
   unsigned char uch_temp;
-  *un_red_led=0;
-  *un_ir_led=0;
-  char ch_i2c_data[6];
+  *pun_red_led=0;
+  *pun_ir_led=0;
+  char ach_i2c_data[6];
   
   //read and clear status register
   maxim_max30102_read_reg(REG_INTR_STATUS_1, &uch_temp);
   maxim_max30102_read_reg(REG_INTR_STATUS_2, &uch_temp);
   
-  ch_i2c_data[0]=REG_FIFO_DATA;
-  if(i2c.write(I2C_WRITE_ADDR, ch_i2c_data, 1, true)!=0)
+  ach_i2c_data[0]=REG_FIFO_DATA;
+  if(i2c.write(I2C_WRITE_ADDR, ach_i2c_data, 1, true)!=0)
     return false;
-  if(i2c.read(I2C_READ_ADDR, ch_i2c_data, 6, false)!=0)
+  if(i2c.read(I2C_READ_ADDR, ach_i2c_data, 6, false)!=0)
   {
     return false;
   }
-  un_temp=(unsigned char) ch_i2c_data[0];
+  un_temp=(unsigned char) ach_i2c_data[0];
   un_temp<<=16;
-  *un_red_led+=un_temp;
-  un_temp=(unsigned char) ch_i2c_data[1];
+  *pun_red_led+=un_temp;
+  un_temp=(unsigned char) ach_i2c_data[1];
   un_temp<<=8;
-  *un_red_led+=un_temp;
-  un_temp=(unsigned char) ch_i2c_data[2];
-  *un_red_led+=un_temp;
+  *pun_red_led+=un_temp;
+  un_temp=(unsigned char) ach_i2c_data[2];
+  *pun_red_led+=un_temp;
   
-  un_temp=(unsigned char) ch_i2c_data[3];
+  un_temp=(unsigned char) ach_i2c_data[3];
   un_temp<<=16;
-  *un_ir_led+=un_temp;
-  un_temp=(unsigned char) ch_i2c_data[4];
+  *pun_ir_led+=un_temp;
+  un_temp=(unsigned char) ach_i2c_data[4];
   un_temp<<=8;
-  *un_ir_led+=un_temp;
-  un_temp=(unsigned char) ch_i2c_data[5];
-  *un_ir_led+=un_temp;
-  *un_red_led&=0x03FFFF;  //Mask MSB [23:18]
-  *un_ir_led&=0x03FFFF;  //Mask MSB [23:18]
+  *pun_ir_led+=un_temp;
+  un_temp=(unsigned char) ach_i2c_data[5];
+  *pun_ir_led+=un_temp;
+  *pun_red_led&=0x03FFFF;  //Mask MSB [23:18]
+  *pun_ir_led&=0x03FFFF;  //Mask MSB [23:18]
   
   
   return true;
@@ -80,24 +80,24 @@
 *
 * \param[in]    uch_addr    - register address
-* \param[out]   uch_data    - pointer that stores the register data
+* \param[out]   puch_data    - pointer that stores the register data
 *
 * \retval       true on success
@@ -152,54 +152,54 @@
 *               This function reads a set of samples from the MAX30102 FIFO register
 *
-* \param[out]   *un_red_led   - pointer that stores the red LED reading data
-* \param[out]   *un_ir_led    - pointer that stores the IR LED reading data
+* \param[out]   *pun_red_led   - pointer that stores the red LED reading data
+* \param[out]   *pun_ir_led    - pointer that stores the IR LED reading data
 *
 * \retval       true on success